.. _about:

About
=====

The `Scikit-HEP project` is a community-driven and community-oriented project
with the aim of providing Particle Physics at large with a Python package
containing core and common tools. The project started in Autumn 2016 and is under active development.

For what concerns Python packages, the project can be seen as a "core package" and a set of :ref:`affiliated packages <affiliations>`.
It is not just about providing common tools for the community. It is also about improving on discoverability of utility packages.

The software package defines a set of five *pillars*, which are seen to embrace
all major topics involved in a physicist's work. These are:

  * **Datasets**: data in various sources, such as ROOT, Numpy/Pandas, databases, wrapped in a common interface.
  * **Aggregations**: e.g. histograms that summarize or project a dataset.
  * **Modeling**: data models and fitting utilities.
  * **Simulation**: wrappers for Monte Carlo engines and other generators of simulated data.
  * **Visualization**: interface to graphics engines, from ROOT and Matplotlib to maybe even d3 or plot.ly.

Core team
---------

Project startup team:

  * Vanya Belyaev (ITEP, Moscow - LHCb)
  * Noel Dawe (University of Melbourne - ATLAS)
  * David Lange (Princeton University - CMS, DIANA)
  * Sasha Mazurov (University of Birmingham - LHCb)
  * Alex Pearce (CERN - LHCb)
  * Jim Pivarski (Princeton University - CMS, DIANA)
  * Eduardo Rodrigues (University of Cincinnati - DIANA, LHCb)

Experiment contact persons
--------------------------

Contact persons are being identified for "each" experiment.
It is expected that contact persons get involved with the project in 3 ways:

  * Act as a bridge between the Scikit-HEP team and the experiment.
  * Provide feedback on the expectations the experiment (analysts) have.
  * Provide feedback on Scikit-HEP directions, code functionality and alike.

The current list of contact persons is the following:

    ===================   =================================
    Experiment            Name(s)
    ===================   =================================
    Belle II              Karim Trabelsi, Nils Braun
    CMS                   Valentin Kuznetsov
    DUNE                  Dorota Stefan, Robert Sulej
    LHCb                  Matthieu Marinangeli
    Mu2e                  Brian Pollack
    ===================   =================================

Contributors
------------

Every project (sub)package is under the responsibility of a coordinator/maintainer.
The list will be provided in due time.

We look forward to contributions from the community!
Please refer to the link :ref:`contributing to Scikit-HEP <contributing>`
for details on how to get involved.

Other credits
.............

* Thank you to Alex Pearce for designing the starting website.

Licensing
---------

The software package is under a BSD 3-clause license.
